@@ -12,45 +12,60 @@ import click
 
 from osducli.click_cli import State, global_params
 from osducli.cliclient import handle_cli_exceptions
-from osducli.commands.config.consts import (AUTHENTICATION_LIST, MSG_CLOSING,
-                                            MSG_GLOBAL_SETTINGS_LOCATION,
-                                            MSG_INTRO, MSG_PROMPT_ACL_OWNER,
-                                            MSG_PROMPT_ACL_VIEWER,
-                                            MSG_PROMPT_AUTHENTICATION_MODE,
-                                            MSG_PROMPT_AUTHORITY,
-                                            MSG_PROMPT_CLIENT_ID,
-                                            MSG_PROMPT_CLIENT_SECRET,
-                                            MSG_PROMPT_CONFIG_ENTITLEMENTS_URL,
-                                            MSG_PROMPT_DATA_PARTITION,
-                                            MSG_PROMPT_FILE_URL,
-                                            MSG_PROMPT_GLOBAL_OUTPUT,
-                                            MSG_PROMPT_LEGAL_TAG,
-                                            MSG_PROMPT_MANAGE_GLOBAL,
-                                            MSG_PROMPT_REFRESH_TOKEN,
-                                            MSG_PROMPT_SCHEMA_URL,
-                                            MSG_PROMPT_SCOPES,
-                                            MSG_PROMPT_SEARCH_URL,
-                                            MSG_PROMPT_SERVER,
-                                            MSG_PROMPT_STORAGE_URL,
-                                            MSG_PROMPT_TOKEN_ENDPOINT_URL,
-                                            MSG_PROMPT_UNIT_URL,
-                                            MSG_PROMPT_WORKFLOW_URL,
-                                            OUTPUT_LIST)
+from osducli.commands.config.consts import (
+    AUTHENTICATION_LIST,
+    MSG_CLOSING,
+    MSG_GLOBAL_SETTINGS_LOCATION,
+    MSG_INTRO,
+    MSG_PROMPT_ACL_OWNER,
+    MSG_PROMPT_ACL_VIEWER,
+    MSG_PROMPT_AUTHENTICATION_MODE,
+    MSG_PROMPT_AUTHORITY,
+    MSG_PROMPT_CLIENT_ID,
+    MSG_PROMPT_CLIENT_SECRET,
+    MSG_PROMPT_CONFIG_ENTITLEMENTS_URL,
+    MSG_PROMPT_DATA_PARTITION,
+    MSG_PROMPT_FILE_URL,
+    MSG_PROMPT_GLOBAL_OUTPUT,
+    MSG_PROMPT_LEGAL_TAG,
+    MSG_PROMPT_MANAGE_GLOBAL,
+    MSG_PROMPT_REFRESH_TOKEN,
+    MSG_PROMPT_SCHEMA_URL,
+    MSG_PROMPT_SCOPES,
+    MSG_PROMPT_SEARCH_URL,
+    MSG_PROMPT_SERVER,
+    MSG_PROMPT_STORAGE_URL,
+    MSG_PROMPT_TOKEN_ENDPOINT_URL,
+    MSG_PROMPT_UNIT_URL,
+    MSG_PROMPT_WORKFLOW_URL,
+    OUTPUT_LIST,
+)
 from osducli.commands.config.list import print_cur_configuration
-from osducli.config import (CONFIG_ACL_OWNER, CONFIG_ACL_VIEWER,
-                            CONFIG_AUTHENTICATION_AUTHORITY,
-                            CONFIG_AUTHENTICATION_MODE,
-                            CONFIG_AUTHENTICATION_SCOPES, CONFIG_CLIENT_ID,
-                            CONFIG_CLIENT_SECRET, CONFIG_DATA_PARTITION_ID,
-                            CONFIG_ENTITLEMENTS_URL, CONFIG_FILE_URL,
-                            CONFIG_LEGAL_TAG, CONFIG_REFRESH_TOKEN,
-                            CONFIG_SCHEMA_URL, CONFIG_SEARCH_URL,
-                            CONFIG_SERVER, CONFIG_STORAGE_URL,
-                            CONFIG_TOKEN_ENDPOINT, CONFIG_UNIT_URL,
-                            CONFIG_WORKFLOW_URL, CLIConfig,
-                            get_default_choice_index_from_config,
-                            get_default_from_config)
-from osducli.prompt import prompt, prompt_choice_list, prompt_y_n
+from osducli.config import (
+    CONFIG_ACL_OWNER,
+    CONFIG_ACL_VIEWER,
+    CONFIG_AUTHENTICATION_AUTHORITY,
+    CONFIG_AUTHENTICATION_MODE,
+    CONFIG_AUTHENTICATION_SCOPES,
+    CONFIG_CLIENT_ID,
+    CONFIG_CLIENT_SECRET,
+    CONFIG_DATA_PARTITION_ID,
+    CONFIG_ENTITLEMENTS_URL,
+    CONFIG_FILE_URL,
+    CONFIG_LEGAL_TAG,
+    CONFIG_REFRESH_TOKEN,
+    CONFIG_SCHEMA_URL,
+    CONFIG_SEARCH_URL,
+    CONFIG_SERVER,
+    CONFIG_STORAGE_URL,
+    CONFIG_TOKEN_ENDPOINT,
+    CONFIG_UNIT_URL,
+    CONFIG_WORKFLOW_URL,
+    CLIConfig,
+    get_default_choice_index_from_config,
+    get_default_from_config,
+)
+from osducli.util.prompt import prompt, prompt_choice_list, prompt_y_n
 
 # from osducli.util import is_help_command
 
