@@ -8,6 +8,9 @@
 
 import configparser
 import os
+import stat
+
+from osducli.util.file import ensure_directory_exists
 
 _UNSET = object()
 
@@ -157,12 +160,12 @@ class CLIConfig:
         return CLIConfig._BOOLEAN_STATES[val.lower()]
 
     def set(self, config):
-        # ensure_dir(self.config_dir)
+        ensure_directory_exists(self.config_dir)
         with open(self.config_path, "w") as configfile:
             # if self.config_comment:
             #     configfile.write(self.config_comment + '\n')
             config.write(configfile)
-        os.chmod(self.config_path, os.stat.S_IRUSR | os.stat.S_IWUSR)
+        os.chmod(self.config_path, stat.S_IRUSR | stat.S_IWUSR)
         self.config_parser.read(self.config_path)
 
     def set_value(self, section, option, value):
